tidy.formula.hierarchical: Shorten a Hierarchical Formula
Description
Simplify a formula, assuming it is hierarchical, that is,
an interaction implies all lower-order interactions and main
effects involving the same variables are in the model.
Usage
tidy.formula.hierarchical(formula)
Value
A character string coercible to a formula equivalent to the input.